@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '5.010';
+our $VERSION = '5.011';
 
 sub new {
     my ($class) = @_;
@@ -95,7 +95,10 @@ sub PT::Group::X {
 sub PT::NonSyntaxClass::X {
     my ($class, $className) = @_;
     my $nonSyntax = $class->{''};
-
+    
+    my @nonSyntax = split(" ", $nonSyntax);
+    $nonSyntax = $nonSyntax[0];
+    
     print "SyntaxError", "\n";
     print "===========", "\n";
     print "ClassName: ", $className, "\n";
@@ -379,11 +382,18 @@ sub PT::Block::X {
 sub PT::NonSyntaxFunction::X {
     my ($class, $className, $functionName) = @_;
     my $nonSyntax = $class->{''};
+    
+    my @nonSyntax = split(" ", $nonSyntax);
+    $nonSyntax = $nonSyntax[0];
 
     print "SyntaxError", "\n";
     print "===========", "\n";
     print "ClassName: ", $className, "\n";
-    print "FunctionName: ", $functionName, "\n";
+    
+    if(defined $functionName) { 
+    	print "FunctionName: ", $functionName, "\n";
+    }
+    
     die "Error: $nonSyntax \n";
 }
 
@@ -1327,7 +1337,7 @@ my $parser = qr {
 
     <objrule:  PT::Group>                      <ws: (\s++)*> <Comment> | <Parent> | <Packages> | <EmbedBlock> | <Function> | <NonSyntaxClass>
 
-    <objtoken: PT::NonSyntaxClass>             \b.*?\b
+    <objtoken: PT::NonSyntaxClass>             \b.*\b
 
     <objrule:  PT::Comment>                    [#] <LineComment> @
     <objtoken: PT::LineComment>                .*?
@@ -1362,7 +1372,7 @@ my $parser = qr {
 
     <objrule:  PT::Block>                      <IfElse> | <While> | <ForEach> | <For> | <EmbedBlock> | <Comment> | <Statement> | <NonSyntaxFunction>
 
-    <objtoken: PT::NonSyntaxFunction>          \b.*?\b
+    <objtoken: PT::NonSyntaxFunction>          \b.*\b
 
     <objrule:  PT::EmbedBlock>                 <TokenEmbedBlock> <EmbedCodeBlock>
     <objrule:  PT::EmbedCodeBlock>             <EmbedBegin> <EmbeddedCode> <EmbedEnd>
